@@ -50,13 +50,13 @@ class Extractor:
                                 n_meters=0,
                                 performance_report=0)
 
+        sessions_df = session_streamer.to_pandas(columns_to_anonymize=[])
         if self.TLS:
-            sessions_df = session_streamer.to_pandas(columns_to_anonymize=[])
             config_filepath = path.join(path.dirname(__file__), 'tools/config.json')
             sessions_df = extract_tls_features_and_merge(sessions_df, self.input_pcap_filepath, config_filepath)
-            sessions_df.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False, mode='a' if append else 'w', header=not append)
-        else:
-            session_streamer.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False, mode='a' if append else 'w', header=not append)
+            
+        sessions_df['filepath'] = self.input_pcap_filepath
+        sessions_df.to_csv(path.join(self.output_dirpath,'out-sessions.csv'), index=False, mode='a' if append else 'w', header=not append)
 
         # Hosts
         # HostsProcessor(sessions_df, self.output_dirpath).process()
